@@ -1,7 +1,7 @@
 package WWW::PAUSE::Simple;
 
 our $DATE = '2015-07-07'; # DATE
-our $VERSION = '0.23'; # VERSION
+our $VERSION = '0.24'; # VERSION
 
 use 5.010001;
 use strict;
@@ -441,10 +441,11 @@ sub list_dists {
             $log->debugf("Skipping %s: under a subdirectory", $file);
             next;
         }
-        my ($dist, $version, $is_dev) = _parse_release_filename($file) or do {
+        my ($dist, $version, $is_dev) = _parse_release_filename($file);
+        unless (defined $dist) {
             $log->debugf("Skipping %s: doesn't match release regex", $file);
             next;
-        };
+        }
         next if $is_dev && $newest_n;
         push @dists, {
             name => $dist,
@@ -713,7 +714,7 @@ WWW::PAUSE::Simple - An API for PAUSE
 
 =head1 VERSION
 
-This document describes version 0.23 of WWW::PAUSE::Simple (from Perl distribution WWW-PAUSE-Simple), released on 2015-07-07.
+This document describes version 0.24 of WWW::PAUSE::Simple (from Perl distribution WWW-PAUSE-Simple), released on 2015-07-07.
 
 =head1 SYNOPSIS
 
